@@ -90,9 +90,9 @@ class Config(Model):
     A class for validating configurations supplied to Database.
 
     Attributes:
-        root_directory (str or Path): Root directory to recurse.
-        hidebound_directory (str or Path): Directory where hidebound data will
-            be saved.
+        ingress_directory (str or Path): Root directory to recurse.
+        staging_directory (str or Path): Directory where hidebound data will be
+            staged.
         specification_files (list[str], optional): List of asset specification
             files. Default: [].
         include_regex (str, optional): Include filenames that match this regex.
@@ -104,10 +104,10 @@ class Config(Model):
         exporters (dict, optional): Dictionary of exporter configs, where the
             key is the exporter name and the value is its config. Default: {}.
     '''
-    root_directory = StringType(
+    ingress_directory = StringType(
         required=True, validators=[vd.is_directory]
     )  # type: StringType
-    hidebound_directory = StringType(
+    staging_directory = StringType(
         required=True, validators=[vd.is_directory, vd.is_hidebound_directory]
     )  # type: StringType
     specification_files = ListType(
