@@ -1,12 +1,12 @@
 from typing import Any, Dict, List, Optional
-import flask
 
 import re
 
+from dash import dash_table, dcc, html
 from pandas import DataFrame
 import dash
-from dash import dash_table, dcc, html
 import dash_cytoscape as cyto
+import flask
 import rolling_pin.blob_etl as blob_etl
 # ------------------------------------------------------------------------------
 
@@ -54,14 +54,15 @@ FONT_FAMILY = 'sans-serif, "sans serif"'  # type: str
 
 
 # APP---------------------------------------------------------------------------
-def get_dash_app(server, storage_type='memory'):
-    # type: (flask.Flask, str) -> dash.Dash
+def get_dash_app(server, seconds=5.0, storage_type='session'):
+    # type: (flask.Flask, float, str) -> dash.Dash
     '''
     Generate Dash Flask app instance.
 
     Args:
         server (Flask): Flask instance.
-        storage_type (str): Storage type (used for testing). Default: memory.
+        seconds (float, optional): Time between progress updates. Default: 5.
+        storage_type (str): Storage type (used for testing). Default: session.
 
     Returns:
         Dash: Dash app instance.
@@ -130,27 +131,27 @@ def get_dash_app(server, storage_type='memory'):
             )
         ],
     )
-    content = dcc.Loading(
-        id="content",
-        className='content',
-        type="dot",
-        style={
-            'align-items': 'center',
-            'opacity': '50%',
-            'background': COLOR_SCHEME['bg'],
-        },
-        fullscreen=True,
-        color=COLOR_SCHEME['cyan2'],
+    content = html.Div(
+        id="content-container",
+        className='content-container',
+        children=[
+            html.Div(
+                id="progressbar-container", className='progressbar-container',
+            ),
+            html.Div(id="content", className='content')
+        ],
     )
+    clock = dcc.Interval(id='clock', interval=int(seconds * 1000))
 
     app = dash.Dash(
+        server=server,
         name='hidebound',
         title='Hidebound',
-        server=server,
+        update_title=None,
         external_stylesheets=['/static/style.css'],
+        suppress_callback_exceptions=True,
     )
-    app.layout = html.Div(id='layout', children=[store, tabs, content])
-    app.config['suppress_callback_exceptions'] = True
+    app.layout = html.Div(id='layout', children=[store, clock, tabs, content])
 
     return app
 
@@ -297,7 +298,7 @@ def get_configbar(config):
             children=[expander, spacer, upload, spacer, write],
         ),
         html.Div(className='row-spacer'),
-        html.Div(id='config-content', children=[
+        html.Div(id='config', children=[
             get_key_value_card(config, header='config', id_='config-card')
         ])
     ]
@@ -305,6 +306,39 @@ def get_configbar(config):
     return configbar
 
 
+def get_progressbar(data):
+    # type: (dict) -> html.Div
+    '''
+    Creates a progress bar given progress data.
+
+    Args:
+        data (dict): Progress dictionary.
+
+    Returns:
+        Div: Progress bar.
+    '''
+    temp = dict(message='', progress=1.0)  # type: dict
+    if data is None:
+        data = {}
+    temp.update(data)
+
+    pct = temp['progress']  # type: float
+    width = f'{pct * 100:.0f}%'
+
+    title = html.Div(
+        id='progressbar-title',
+        className='progressbar-title',
+        children=temp['message'],
+    )
+    body = html.Div(
+        id='progressbar-body',
+        className='progressbar-body',
+        style=dict(width=width)
+    )
+    progressbar = html.Div(id='progressbar', children=[title, body])
+    return progressbar
+
+
 # ELEMENTS----------------------------------------------------------------------
 def get_dropdown(options):
     # type: (List[str]) -> dcc.Dropdown
