@@ -1,5 +1,6 @@
-from typing import Any, Dict, Tuple, Union
+from typing import Any, Dict, Optional, Union
 
+from dataclasses import dataclass
 from pathlib import Path
 from pprint import pformat
 import base64
@@ -7,10 +8,36 @@ import json
 import os
 import traceback
 
+from flask.testing import FlaskClient
 import flask
 import jinja2
-import jsoncomment as jsonc
 import lunchbox.tools as lbt
+import requests
+
+import hidebound.core.logging as hblog
+# ------------------------------------------------------------------------------
+
+
+HOST = '0.0.0.0'
+PORT = 8080
+
+
+@dataclass
+class EndPoints:
+    '''
+    A convenience class for API endpoints.
+    '''
+    host = HOST
+    port = PORT
+    api = f'http://{HOST}:{PORT}/api'
+    init = f'http://{HOST}:{PORT}/api/initialize'
+    update = f'http://{HOST}:{PORT}/api/update'
+    create = f'http://{HOST}:{PORT}/api/create'
+    export = f'http://{HOST}:{PORT}/api/export'
+    delete = f'http://{HOST}:{PORT}/api/delete'
+    read = f'http://{HOST}:{PORT}/api/read'
+    search = f'http://{HOST}:{PORT}/api/search'
+    progress = f'http://{HOST}:{PORT}/api/progress'
 # ------------------------------------------------------------------------------
 
 
@@ -30,7 +57,7 @@ def render_template(filename, parameters):
     tempdir = lbt.relative_path(__file__, '../templates').as_posix()
 
     # path to templates inside repo
-    if 'REPO_ENV' in os.environ.keys():
+    if os.environ.get('REPO_ENV', 'False').lower() == 'true':
         tempdir = lbt.relative_path(__file__, '../../../templates').as_posix()
 
     env = jinja2.Environment(
@@ -102,44 +129,16 @@ def error_to_response(error):
 
 
 # SETUP-------------------------------------------------------------------------
-def setup_hidebound_directory(root, config_path=None):
-    # type: (Union[str, Path], Union[str, Path, None]) -> Tuple[Dict, str]
+def setup_hidebound_directories(root):
+    # type: (Union[str, Path]) -> None
     '''
-    Creates [root]/hidebound and [root]/hidebound/config directories.
-    Writes a default hidebound config to
-    [root]/hidebound/config/hidebound_config.json if one does not exist.
+    Creates [root]/ingress, [root]/hidebound and [root]/archive directories.
 
     Args:
-        root (str or Path): Root directory of hidebound data.
-        config_path (str or Path, optional): Filepath of config data to be
-            written to [root]/hidebound/config/hidebound_config.json.
-            Default: None.
-
-    Return:
-        tuple[dict, str]: Config data and filepath.
+        root (str or Path): Root directory.
     '''
-    root = Path(root)
-    hb_root = Path(root, 'hidebound').as_posix()
-    config_dir = Path(hb_root, 'config')
-    os.makedirs(config_dir, exist_ok=True)
-    target = Path(config_dir, 'hidebound_config.json').as_posix()
-
-    config = {
-        'root_directory': Path(root, 'projects').as_posix(),
-        'hidebound_directory': hb_root,
-        'specification_files': [],
-        'include_regex': '',
-        'exclude_regex': r'\.DS_Store',
-        'write_mode': 'copy'
-    }
-    if config_path is not None:
-        with open(config_path) as f:
-            config = jsonc.JsonComment().load(f)
-
-    with open(target, 'w') as f:
-        json.dump(config, f, indent=4, sort_keys=True)
-
-    return config, target
+    for folder in ['ingress', 'hidebound', 'archive']:
+        os.makedirs(Path(root, folder), exist_ok=True)
 
 
 # ERRORS------------------------------------------------------------------------
@@ -220,3 +219,70 @@ def get_connection_error():
     msg = 'Database not connected.'
     error = RuntimeError(msg)
     return error_to_response(error)
+
+
+# DASH-TOOLS--------------------------------------------------------------------
+def get_progress(logpath=hblog.PROGRESS_LOG_PATH):
+    # type: (Union[str, Path]) -> dict
+    '''
+    Gets current progress state.
+
+    Args:
+        logpath (str or Path, optional): Filepath of progress log.
+            Default: PROGRESS_LOG_PATH.
+
+    Returns:
+        dict: Progess.
+    '''
+    state = dict(progress=1.0, message='unknown state')
+    state.update(hblog.get_progress(logpath))
+    return state
+
+
+def request(store, url, params=None, client=requests):
+    # type: (dict, str, Optional[dict], Any) -> dict
+    '''
+    Execute search against database and update store with response.
+    Sets store['content'] to response if there is an error.
+
+    Args:
+        store (dict): Dash store.
+        url (str): API endpoint.
+        params (dict, optional): Request paramaters. Default: None.
+        client (object, optional): Client. Default: requests module.
+
+    Returns:
+        dict: Store.
+    '''
+    params_ = None
+    if params is not None:
+        params_ = json.dumps(params)
+    response = client.post(url, json=params_)
+    code = response.status_code
+    if isinstance(client, FlaskClient):
+        response = response.json
+    else:
+        response = response.json()  # pragma: no cover
+    if code < 200 or code >= 300:
+        store['content'] = response
+    return response
+
+
+def search(store, query, group_by_asset, client=requests):
+    # type: (dict, str, bool, Any) -> dict
+    '''
+    Execute search against database and update given store with response.
+
+    Args:
+        store (dict): Dash store.
+        query (str): Query string.
+        group_by_asset (bool): Whether to group the search by asset.
+        client (object, optional): Client. Default: requests module.
+
+    Returns:
+        dict: Store.
+    '''
+    params = dict(query=query, group_by_asset=group_by_asset)
+    store['content'] = request(store, EndPoints().search, params, client)
+    store['query'] = query
+    return store
